#ifndef INSTRUCTORSVIEW_H
#define INSTRUCTORSVIEW_H

#include "instructorsAndTrainees_global.h"
#include "commonview.h"

//Родительский класс представления БД Инструкторов (для просмотра и управления)

class InstructorsView: public CommonView
{
    Q_OBJECT

public:
    InstructorsView(InterfaceDataBaseLMS* dbLMS, TypeView type, QWidget *parent = nullptr);

protected:
    enum ColumnsTreeInsructors{
        clmn_Instructor = 0,
        clmn_Login,
        clmn_Password,
        clmn_Administrator,
        clmn_Archived,
        clmn_Logged,
        clmn_ID
    };

public Q_SLOTS:
    //Слот обработки сигнала необходимости обновления интерфейса
    void slot_NeedUpdateUI(bool treeInstructor, bool treeTrainee);

protected:
    virtual void updateButtons(){};
    void preparationTreeWidget(/*QTreeWidget* tree*/);
    void loadInstructorsFromDB();

    void reSetHeadTreeWidget();
};

#endif // INSTRUCTORSVIEW_H
